# pulp_deb_client

PulpDebClient - the Ruby gem for the Pulp 3 API

Fetch, Upload, Organize, and Distribute Software Packages

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 2.15.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build pulp_deb_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./pulp_deb_client-2.15.0.gem
```

(for development, run `gem install --dev ./pulp_deb_client-2.15.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'pulp_deb_client', '~> 2.15.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'pulp_deb_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'pulp_deb_client'

# Setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = PulpDebClient::ContentGenericContentsApi.new
relative_path = 'relative_path_example' # String | Path where the artifact is located relative to distributions base_path
opts = {
  artifact: 'artifact_example', # String | Artifact file representing the physical content
  file: File.new('/path/to/file'), # File | An uploaded file that may be turned into the artifact of the content unit.
  repository: 'repository_example' # String | A URI of a repository the new content unit should be associated with.
}

begin
  #Create a generic content
  result = api_instance.create(relative_path, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentGenericContentsApi->create: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PulpDebClient::ContentGenericContentsApi* | [**create**](docs/ContentGenericContentsApi.md#create) | **POST** /pulp/api/v3/content/deb/generic_contents/ | Create a generic content
*PulpDebClient::ContentGenericContentsApi* | [**list**](docs/ContentGenericContentsApi.md#list) | **GET** /pulp/api/v3/content/deb/generic_contents/ | List generic contents
*PulpDebClient::ContentGenericContentsApi* | [**read**](docs/ContentGenericContentsApi.md#read) | **GET** {deb_generic_content_href} | Inspect a generic content
*PulpDebClient::ContentInstallerFileIndicesApi* | [**create**](docs/ContentInstallerFileIndicesApi.md#create) | **POST** /pulp/api/v3/content/deb/installer_file_indices/ | Create an installer file index
*PulpDebClient::ContentInstallerFileIndicesApi* | [**list**](docs/ContentInstallerFileIndicesApi.md#list) | **GET** /pulp/api/v3/content/deb/installer_file_indices/ | List InstallerFileIndices
*PulpDebClient::ContentInstallerFileIndicesApi* | [**read**](docs/ContentInstallerFileIndicesApi.md#read) | **GET** {deb_installer_file_index_href} | Inspect an installer file index
*PulpDebClient::ContentInstallerPackagesApi* | [**create**](docs/ContentInstallerPackagesApi.md#create) | **POST** /pulp/api/v3/content/deb/installer_packages/ | Create an installer package
*PulpDebClient::ContentInstallerPackagesApi* | [**list**](docs/ContentInstallerPackagesApi.md#list) | **GET** /pulp/api/v3/content/deb/installer_packages/ | List installer packages
*PulpDebClient::ContentInstallerPackagesApi* | [**read**](docs/ContentInstallerPackagesApi.md#read) | **GET** {deb_installer_package_href} | Inspect an installer package
*PulpDebClient::ContentPackageIndicesApi* | [**create**](docs/ContentPackageIndicesApi.md#create) | **POST** /pulp/api/v3/content/deb/package_indices/ | Create a package index
*PulpDebClient::ContentPackageIndicesApi* | [**list**](docs/ContentPackageIndicesApi.md#list) | **GET** /pulp/api/v3/content/deb/package_indices/ | List PackageIndices
*PulpDebClient::ContentPackageIndicesApi* | [**read**](docs/ContentPackageIndicesApi.md#read) | **GET** {deb_package_index_href} | Inspect a package index
*PulpDebClient::ContentPackageReleaseComponentsApi* | [**create**](docs/ContentPackageReleaseComponentsApi.md#create) | **POST** /pulp/api/v3/content/deb/package_release_components/ | Create a package release component
*PulpDebClient::ContentPackageReleaseComponentsApi* | [**list**](docs/ContentPackageReleaseComponentsApi.md#list) | **GET** /pulp/api/v3/content/deb/package_release_components/ | List package release components
*PulpDebClient::ContentPackageReleaseComponentsApi* | [**read**](docs/ContentPackageReleaseComponentsApi.md#read) | **GET** {deb_package_release_component_href} | Inspect a package release component
*PulpDebClient::ContentPackagesApi* | [**create**](docs/ContentPackagesApi.md#create) | **POST** /pulp/api/v3/content/deb/packages/ | Create a package
*PulpDebClient::ContentPackagesApi* | [**list**](docs/ContentPackagesApi.md#list) | **GET** /pulp/api/v3/content/deb/packages/ | List packages
*PulpDebClient::ContentPackagesApi* | [**read**](docs/ContentPackagesApi.md#read) | **GET** {deb_package_href} | Inspect a package
*PulpDebClient::ContentReleaseArchitecturesApi* | [**create**](docs/ContentReleaseArchitecturesApi.md#create) | **POST** /pulp/api/v3/content/deb/release_architectures/ | Create a release architecture
*PulpDebClient::ContentReleaseArchitecturesApi* | [**list**](docs/ContentReleaseArchitecturesApi.md#list) | **GET** /pulp/api/v3/content/deb/release_architectures/ | List release architectures
*PulpDebClient::ContentReleaseArchitecturesApi* | [**read**](docs/ContentReleaseArchitecturesApi.md#read) | **GET** {deb_release_architecture_href} | Inspect a release architecture
*PulpDebClient::ContentReleaseComponentsApi* | [**create**](docs/ContentReleaseComponentsApi.md#create) | **POST** /pulp/api/v3/content/deb/release_components/ | Create a release component
*PulpDebClient::ContentReleaseComponentsApi* | [**list**](docs/ContentReleaseComponentsApi.md#list) | **GET** /pulp/api/v3/content/deb/release_components/ | List release components
*PulpDebClient::ContentReleaseComponentsApi* | [**read**](docs/ContentReleaseComponentsApi.md#read) | **GET** {deb_release_component_href} | Inspect a release component
*PulpDebClient::ContentReleaseFilesApi* | [**create**](docs/ContentReleaseFilesApi.md#create) | **POST** /pulp/api/v3/content/deb/release_files/ | Create a release file
*PulpDebClient::ContentReleaseFilesApi* | [**list**](docs/ContentReleaseFilesApi.md#list) | **GET** /pulp/api/v3/content/deb/release_files/ | List release files
*PulpDebClient::ContentReleaseFilesApi* | [**read**](docs/ContentReleaseFilesApi.md#read) | **GET** {deb_release_file_href} | Inspect a release file
*PulpDebClient::ContentReleasesApi* | [**create**](docs/ContentReleasesApi.md#create) | **POST** /pulp/api/v3/content/deb/releases/ | Create a release
*PulpDebClient::ContentReleasesApi* | [**list**](docs/ContentReleasesApi.md#list) | **GET** /pulp/api/v3/content/deb/releases/ | List releases
*PulpDebClient::ContentReleasesApi* | [**read**](docs/ContentReleasesApi.md#read) | **GET** {deb_release_href} | Inspect a release
*PulpDebClient::DistributionsAptApi* | [**create**](docs/DistributionsAptApi.md#create) | **POST** /pulp/api/v3/distributions/deb/apt/ | Create an apt distribution
*PulpDebClient::DistributionsAptApi* | [**delete**](docs/DistributionsAptApi.md#delete) | **DELETE** {deb_apt_distribution_href} | Delete an apt distribution
*PulpDebClient::DistributionsAptApi* | [**list**](docs/DistributionsAptApi.md#list) | **GET** /pulp/api/v3/distributions/deb/apt/ | List apt distributions
*PulpDebClient::DistributionsAptApi* | [**partial_update**](docs/DistributionsAptApi.md#partial_update) | **PATCH** {deb_apt_distribution_href} | Update an apt distribution
*PulpDebClient::DistributionsAptApi* | [**read**](docs/DistributionsAptApi.md#read) | **GET** {deb_apt_distribution_href} | Inspect an apt distribution
*PulpDebClient::DistributionsAptApi* | [**update**](docs/DistributionsAptApi.md#update) | **PUT** {deb_apt_distribution_href} | Update an apt distribution
*PulpDebClient::PublicationsAptApi* | [**create**](docs/PublicationsAptApi.md#create) | **POST** /pulp/api/v3/publications/deb/apt/ | Create an apt publication
*PulpDebClient::PublicationsAptApi* | [**delete**](docs/PublicationsAptApi.md#delete) | **DELETE** {deb_apt_publication_href} | Delete an apt publication
*PulpDebClient::PublicationsAptApi* | [**list**](docs/PublicationsAptApi.md#list) | **GET** /pulp/api/v3/publications/deb/apt/ | List apt publications
*PulpDebClient::PublicationsAptApi* | [**read**](docs/PublicationsAptApi.md#read) | **GET** {deb_apt_publication_href} | Inspect an apt publication
*PulpDebClient::PublicationsVerbatimApi* | [**create**](docs/PublicationsVerbatimApi.md#create) | **POST** /pulp/api/v3/publications/deb/verbatim/ | Create a verbatim publication
*PulpDebClient::PublicationsVerbatimApi* | [**delete**](docs/PublicationsVerbatimApi.md#delete) | **DELETE** {deb_verbatim_publication_href} | Delete a verbatim publication
*PulpDebClient::PublicationsVerbatimApi* | [**list**](docs/PublicationsVerbatimApi.md#list) | **GET** /pulp/api/v3/publications/deb/verbatim/ | List verbatim publications
*PulpDebClient::PublicationsVerbatimApi* | [**read**](docs/PublicationsVerbatimApi.md#read) | **GET** {deb_verbatim_publication_href} | Inspect a verbatim publication
*PulpDebClient::RemotesAptApi* | [**create**](docs/RemotesAptApi.md#create) | **POST** /pulp/api/v3/remotes/deb/apt/ | Create an apt remote
*PulpDebClient::RemotesAptApi* | [**delete**](docs/RemotesAptApi.md#delete) | **DELETE** {deb_apt_remote_href} | Delete an apt remote
*PulpDebClient::RemotesAptApi* | [**list**](docs/RemotesAptApi.md#list) | **GET** /pulp/api/v3/remotes/deb/apt/ | List apt remotes
*PulpDebClient::RemotesAptApi* | [**partial_update**](docs/RemotesAptApi.md#partial_update) | **PATCH** {deb_apt_remote_href} | Update an apt remote
*PulpDebClient::RemotesAptApi* | [**read**](docs/RemotesAptApi.md#read) | **GET** {deb_apt_remote_href} | Inspect an apt remote
*PulpDebClient::RemotesAptApi* | [**update**](docs/RemotesAptApi.md#update) | **PUT** {deb_apt_remote_href} | Update an apt remote
*PulpDebClient::RepositoriesAptApi* | [**create**](docs/RepositoriesAptApi.md#create) | **POST** /pulp/api/v3/repositories/deb/apt/ | Create an apt repository
*PulpDebClient::RepositoriesAptApi* | [**delete**](docs/RepositoriesAptApi.md#delete) | **DELETE** {deb_apt_repository_href} | Delete an apt repository
*PulpDebClient::RepositoriesAptApi* | [**list**](docs/RepositoriesAptApi.md#list) | **GET** /pulp/api/v3/repositories/deb/apt/ | List apt repositorys
*PulpDebClient::RepositoriesAptApi* | [**modify**](docs/RepositoriesAptApi.md#modify) | **POST** {deb_apt_repository_href}modify/ | Modify Repository Content
*PulpDebClient::RepositoriesAptApi* | [**partial_update**](docs/RepositoriesAptApi.md#partial_update) | **PATCH** {deb_apt_repository_href} | Update an apt repository
*PulpDebClient::RepositoriesAptApi* | [**read**](docs/RepositoriesAptApi.md#read) | **GET** {deb_apt_repository_href} | Inspect an apt repository
*PulpDebClient::RepositoriesAptApi* | [**sync**](docs/RepositoriesAptApi.md#sync) | **POST** {deb_apt_repository_href}sync/ | Sync from remote
*PulpDebClient::RepositoriesAptApi* | [**update**](docs/RepositoriesAptApi.md#update) | **PUT** {deb_apt_repository_href} | Update an apt repository
*PulpDebClient::RepositoriesAptVersionsApi* | [**delete**](docs/RepositoriesAptVersionsApi.md#delete) | **DELETE** {deb_apt_repository_version_href} | Delete a repository version
*PulpDebClient::RepositoriesAptVersionsApi* | [**list**](docs/RepositoriesAptVersionsApi.md#list) | **GET** {deb_apt_repository_href}versions/ | List repository versions
*PulpDebClient::RepositoriesAptVersionsApi* | [**read**](docs/RepositoriesAptVersionsApi.md#read) | **GET** {deb_apt_repository_version_href} | Inspect a repository version
*PulpDebClient::RepositoriesAptVersionsApi* | [**repair**](docs/RepositoriesAptVersionsApi.md#repair) | **POST** {deb_apt_repository_version_href}repair/ | 


## Documentation for Models

 - [PulpDebClient::AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [PulpDebClient::ContentSummary](docs/ContentSummary.md)
 - [PulpDebClient::ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [PulpDebClient::DebAptDistribution](docs/DebAptDistribution.md)
 - [PulpDebClient::DebAptDistributionResponse](docs/DebAptDistributionResponse.md)
 - [PulpDebClient::DebAptPublication](docs/DebAptPublication.md)
 - [PulpDebClient::DebAptPublicationResponse](docs/DebAptPublicationResponse.md)
 - [PulpDebClient::DebAptRemote](docs/DebAptRemote.md)
 - [PulpDebClient::DebAptRemoteResponse](docs/DebAptRemoteResponse.md)
 - [PulpDebClient::DebAptRepository](docs/DebAptRepository.md)
 - [PulpDebClient::DebAptRepositoryResponse](docs/DebAptRepositoryResponse.md)
 - [PulpDebClient::DebBasePackage](docs/DebBasePackage.md)
 - [PulpDebClient::DebBasePackageResponse](docs/DebBasePackageResponse.md)
 - [PulpDebClient::DebGenericContent](docs/DebGenericContent.md)
 - [PulpDebClient::DebGenericContentResponse](docs/DebGenericContentResponse.md)
 - [PulpDebClient::DebInstallerFileIndex](docs/DebInstallerFileIndex.md)
 - [PulpDebClient::DebInstallerFileIndexResponse](docs/DebInstallerFileIndexResponse.md)
 - [PulpDebClient::DebPackageIndex](docs/DebPackageIndex.md)
 - [PulpDebClient::DebPackageIndexResponse](docs/DebPackageIndexResponse.md)
 - [PulpDebClient::DebPackageReleaseComponent](docs/DebPackageReleaseComponent.md)
 - [PulpDebClient::DebPackageReleaseComponentResponse](docs/DebPackageReleaseComponentResponse.md)
 - [PulpDebClient::DebRelease](docs/DebRelease.md)
 - [PulpDebClient::DebReleaseArchitecture](docs/DebReleaseArchitecture.md)
 - [PulpDebClient::DebReleaseArchitectureResponse](docs/DebReleaseArchitectureResponse.md)
 - [PulpDebClient::DebReleaseComponent](docs/DebReleaseComponent.md)
 - [PulpDebClient::DebReleaseComponentResponse](docs/DebReleaseComponentResponse.md)
 - [PulpDebClient::DebReleaseFile](docs/DebReleaseFile.md)
 - [PulpDebClient::DebReleaseFileResponse](docs/DebReleaseFileResponse.md)
 - [PulpDebClient::DebReleaseResponse](docs/DebReleaseResponse.md)
 - [PulpDebClient::DebVerbatimPublication](docs/DebVerbatimPublication.md)
 - [PulpDebClient::DebVerbatimPublicationResponse](docs/DebVerbatimPublicationResponse.md)
 - [PulpDebClient::PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PulpDebClient::PaginateddebAptDistributionResponseList](docs/PaginateddebAptDistributionResponseList.md)
 - [PulpDebClient::PaginateddebAptPublicationResponseList](docs/PaginateddebAptPublicationResponseList.md)
 - [PulpDebClient::PaginateddebAptRemoteResponseList](docs/PaginateddebAptRemoteResponseList.md)
 - [PulpDebClient::PaginateddebAptRepositoryResponseList](docs/PaginateddebAptRepositoryResponseList.md)
 - [PulpDebClient::PaginateddebBasePackageResponseList](docs/PaginateddebBasePackageResponseList.md)
 - [PulpDebClient::PaginateddebGenericContentResponseList](docs/PaginateddebGenericContentResponseList.md)
 - [PulpDebClient::PaginateddebInstallerFileIndexResponseList](docs/PaginateddebInstallerFileIndexResponseList.md)
 - [PulpDebClient::PaginateddebPackageIndexResponseList](docs/PaginateddebPackageIndexResponseList.md)
 - [PulpDebClient::PaginateddebPackageReleaseComponentResponseList](docs/PaginateddebPackageReleaseComponentResponseList.md)
 - [PulpDebClient::PaginateddebReleaseArchitectureResponseList](docs/PaginateddebReleaseArchitectureResponseList.md)
 - [PulpDebClient::PaginateddebReleaseComponentResponseList](docs/PaginateddebReleaseComponentResponseList.md)
 - [PulpDebClient::PaginateddebReleaseFileResponseList](docs/PaginateddebReleaseFileResponseList.md)
 - [PulpDebClient::PaginateddebReleaseResponseList](docs/PaginateddebReleaseResponseList.md)
 - [PulpDebClient::PaginateddebVerbatimPublicationResponseList](docs/PaginateddebVerbatimPublicationResponseList.md)
 - [PulpDebClient::PatcheddebAptDistribution](docs/PatcheddebAptDistribution.md)
 - [PulpDebClient::PatcheddebAptRemote](docs/PatcheddebAptRemote.md)
 - [PulpDebClient::PatcheddebAptRepository](docs/PatcheddebAptRepository.md)
 - [PulpDebClient::PolicyEnum](docs/PolicyEnum.md)
 - [PulpDebClient::RepositoryAddRemoveContent](docs/RepositoryAddRemoveContent.md)
 - [PulpDebClient::RepositorySyncURL](docs/RepositorySyncURL.md)
 - [PulpDebClient::RepositoryVersion](docs/RepositoryVersion.md)
 - [PulpDebClient::RepositoryVersionResponse](docs/RepositoryVersionResponse.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

