# PulpDebClient::ContentInstallerFileIndicesApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentInstallerFileIndicesApi.md#create) | **POST** /pulp/api/v3/content/deb/installer_file_indices/ | Create an installer file index
[**list**](ContentInstallerFileIndicesApi.md#list) | **GET** /pulp/api/v3/content/deb/installer_file_indices/ | List InstallerFileIndices
[**read**](ContentInstallerFileIndicesApi.md#read) | **GET** {deb_installer_file_index_href} | Inspect an installer file index



## create

> DebInstallerFileIndexResponse create(deb_installer_file_index)

Create an installer file index

An InstallerFileIndex represents the indices for a set of installer files.  Associated artifacts: Exactly one 'SHA256SUMS' and/or 'MD5SUMS' file.  Each InstallerFileIndes is associated with a single component-architecture combination within a single Release. Note that installer files are currently used exclusively for verbatim publications. The APT publisher (both simple and structured mode) does not make use of installer content.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentInstallerFileIndicesApi.new
deb_installer_file_index = PulpDebClient::DebInstallerFileIndex.new # DebInstallerFileIndex | 

begin
  #Create an installer file index
  result = api_instance.create(deb_installer_file_index)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentInstallerFileIndicesApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_installer_file_index** | [**DebInstallerFileIndex**](DebInstallerFileIndex.md)|  | 

### Return type

[**DebInstallerFileIndexResponse**](DebInstallerFileIndexResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## list

> PaginateddebInstallerFileIndexResponseList list(opts)

List InstallerFileIndices

An InstallerFileIndex represents the indices for a set of installer files.  Associated artifacts: Exactly one 'SHA256SUMS' and/or 'MD5SUMS' file.  Each InstallerFileIndes is associated with a single component-architecture combination within a single Release. Note that installer files are currently used exclusively for verbatim publications. The APT publisher (both simple and structured mode) does not make use of installer content.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentInstallerFileIndicesApi.new
opts = {
  architecture: 'architecture_example', # String | Filter results where architecture matches value
  component: 'component_example', # String | Filter results where component matches value
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  relative_path: 'relative_path_example', # String | Filter results where relative_path matches value
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  sha256: 'sha256_example', # String | Filter results where sha256 matches value
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List InstallerFileIndices
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentInstallerFileIndicesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **architecture** | **String**| Filter results where architecture matches value | [optional] 
 **component** | **String**| Filter results where component matches value | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **relative_path** | **String**| Filter results where relative_path matches value | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **sha256** | **String**| Filter results where sha256 matches value | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebInstallerFileIndexResponseList**](PaginateddebInstallerFileIndexResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> DebInstallerFileIndexResponse read(deb_installer_file_index_href, opts)

Inspect an installer file index

An InstallerFileIndex represents the indices for a set of installer files.  Associated artifacts: Exactly one 'SHA256SUMS' and/or 'MD5SUMS' file.  Each InstallerFileIndes is associated with a single component-architecture combination within a single Release. Note that installer files are currently used exclusively for verbatim publications. The APT publisher (both simple and structured mode) does not make use of installer content.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentInstallerFileIndicesApi.new
deb_installer_file_index_href = 'deb_installer_file_index_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect an installer file index
  result = api_instance.read(deb_installer_file_index_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentInstallerFileIndicesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_installer_file_index_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebInstallerFileIndexResponse**](DebInstallerFileIndexResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

