# PulpDebClient::ContentInstallerPackagesApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentInstallerPackagesApi.md#create) | **POST** /pulp/api/v3/content/deb/installer_packages/ | Create an installer package
[**list**](ContentInstallerPackagesApi.md#list) | **GET** /pulp/api/v3/content/deb/installer_packages/ | List installer packages
[**read**](ContentInstallerPackagesApi.md#read) | **GET** {deb_installer_package_href} | Inspect an installer package



## create

> AsyncOperationResponse create(opts)

Create an installer package

Trigger an asynchronous task to create content,optionally create new repository version.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentInstallerPackagesApi.new
opts = {
  artifact: 'artifact_example', # String | Artifact file representing the physical content
  relative_path: 'relative_path_example', # String | Path where the artifact is located relative to distributions base_path
  file: File.new('/path/to/file'), # File | An uploaded file that may be turned into the artifact of the content unit.
  repository: 'repository_example' # String | A URI of a repository the new content unit should be associated with.
}

begin
  #Create an installer package
  result = api_instance.create(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentInstallerPackagesApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **artifact** | **String**| Artifact file representing the physical content | [optional] 
 **relative_path** | **String**| Path where the artifact is located relative to distributions base_path | [optional] 
 **file** | **File**| An uploaded file that may be turned into the artifact of the content unit. | [optional] 
 **repository** | **String**| A URI of a repository the new content unit should be associated with. | [optional] 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: multipart/form-data, application/x-www-form-urlencoded
- **Accept**: application/json


## list

> PaginateddebBasePackageResponseList list(opts)

List installer packages

An InstallerPackage represents a '.udeb' installer package.  Associated artifacts: Exactly one '.udeb' installer package file.  Note that installer packages are currently used exclusively for verbatim publications. The APT publisher (both simple and structured mode) will not include these packages.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentInstallerPackagesApi.new
opts = {
  architecture: 'architecture_example', # String | Filter results where architecture matches value
  auto_built_package: 'auto_built_package_example', # String | Filter results where auto_built_package matches value
  build_essential: true, # Boolean | Filter results where build_essential matches value
  built_using: 'built_using_example', # String | Filter results where built_using matches value
  essential: true, # Boolean | Filter results where essential matches value
  installed_size: 56, # Integer | Filter results where installed_size matches value
  limit: 56, # Integer | Number of results to return per page.
  maintainer: 'maintainer_example', # String | Filter results where maintainer matches value
  multi_arch: 'multi_arch_example', # String | Filter results where multi_arch matches value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  origin: 'origin_example', # String | Filter results where origin matches value
  original_maintainer: 'original_maintainer_example', # String | Filter results where original_maintainer matches value
  package: 'package_example', # String | Filter results where package matches value
  priority: 'priority_example', # String | Filter results where priority matches value
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  section: 'section_example', # String | Filter results where section matches value
  sha256: 'sha256_example', # String | Filter results where sha256 matches value
  source: 'source_example', # String | Filter results where source matches value
  tag: 'tag_example', # String | Filter results where tag matches value
  version: 'version_example', # String | Filter results where version matches value
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List installer packages
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentInstallerPackagesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **architecture** | **String**| Filter results where architecture matches value | [optional] 
 **auto_built_package** | **String**| Filter results where auto_built_package matches value | [optional] 
 **build_essential** | **Boolean**| Filter results where build_essential matches value | [optional] 
 **built_using** | **String**| Filter results where built_using matches value | [optional] 
 **essential** | **Boolean**| Filter results where essential matches value | [optional] 
 **installed_size** | **Integer**| Filter results where installed_size matches value | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **maintainer** | **String**| Filter results where maintainer matches value | [optional] 
 **multi_arch** | **String**| Filter results where multi_arch matches value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **origin** | **String**| Filter results where origin matches value | [optional] 
 **original_maintainer** | **String**| Filter results where original_maintainer matches value | [optional] 
 **package** | **String**| Filter results where package matches value | [optional] 
 **priority** | **String**| Filter results where priority matches value | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **section** | **String**| Filter results where section matches value | [optional] 
 **sha256** | **String**| Filter results where sha256 matches value | [optional] 
 **source** | **String**| Filter results where source matches value | [optional] 
 **tag** | **String**| Filter results where tag matches value | [optional] 
 **version** | **String**| Filter results where version matches value | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebBasePackageResponseList**](PaginateddebBasePackageResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> DebBasePackageResponse read(deb_installer_package_href, opts)

Inspect an installer package

An InstallerPackage represents a '.udeb' installer package.  Associated artifacts: Exactly one '.udeb' installer package file.  Note that installer packages are currently used exclusively for verbatim publications. The APT publisher (both simple and structured mode) will not include these packages.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentInstallerPackagesApi.new
deb_installer_package_href = 'deb_installer_package_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect an installer package
  result = api_instance.read(deb_installer_package_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentInstallerPackagesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_installer_package_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebBasePackageResponse**](DebBasePackageResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

