# PulpDebClient::ContentPackageIndicesApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentPackageIndicesApi.md#create) | **POST** /pulp/api/v3/content/deb/package_indices/ | Create a package index
[**list**](ContentPackageIndicesApi.md#list) | **GET** /pulp/api/v3/content/deb/package_indices/ | List PackageIndices
[**read**](ContentPackageIndicesApi.md#read) | **GET** {deb_package_index_href} | Inspect a package index



## create

> DebPackageIndexResponse create(deb_package_index)

Create a package index

A PackageIndex represents the package indices of a single component-architecture combination.  Associated artifacts: Exactly one 'Packages' file. May optionally include one or more of 'Packages.gz', 'Packages.xz', 'Release'. If included, the 'Release' file is a legacy per-component-and-architecture Release file.  Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any 'Packages' files it needs when creating the publication. It does not make use of PackageIndex content.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentPackageIndicesApi.new
deb_package_index = PulpDebClient::DebPackageIndex.new # DebPackageIndex | 

begin
  #Create a package index
  result = api_instance.create(deb_package_index)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentPackageIndicesApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_package_index** | [**DebPackageIndex**](DebPackageIndex.md)|  | 

### Return type

[**DebPackageIndexResponse**](DebPackageIndexResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## list

> PaginateddebPackageIndexResponseList list(opts)

List PackageIndices

A PackageIndex represents the package indices of a single component-architecture combination.  Associated artifacts: Exactly one 'Packages' file. May optionally include one or more of 'Packages.gz', 'Packages.xz', 'Release'. If included, the 'Release' file is a legacy per-component-and-architecture Release file.  Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any 'Packages' files it needs when creating the publication. It does not make use of PackageIndex content.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentPackageIndicesApi.new
opts = {
  architecture: 'architecture_example', # String | Filter results where architecture matches value
  component: 'component_example', # String | Filter results where component matches value
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  relative_path: 'relative_path_example', # String | Filter results where relative_path matches value
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  sha256: 'sha256_example', # String | Filter results where sha256 matches value
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List PackageIndices
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentPackageIndicesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **architecture** | **String**| Filter results where architecture matches value | [optional] 
 **component** | **String**| Filter results where component matches value | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **relative_path** | **String**| Filter results where relative_path matches value | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **sha256** | **String**| Filter results where sha256 matches value | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebPackageIndexResponseList**](PaginateddebPackageIndexResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> DebPackageIndexResponse read(deb_package_index_href, opts)

Inspect a package index

A PackageIndex represents the package indices of a single component-architecture combination.  Associated artifacts: Exactly one 'Packages' file. May optionally include one or more of 'Packages.gz', 'Packages.xz', 'Release'. If included, the 'Release' file is a legacy per-component-and-architecture Release file.  Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any 'Packages' files it needs when creating the publication. It does not make use of PackageIndex content.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentPackageIndicesApi.new
deb_package_index_href = 'deb_package_index_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a package index
  result = api_instance.read(deb_package_index_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentPackageIndicesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_package_index_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebPackageIndexResponse**](DebPackageIndexResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

