# PulpDebClient::ContentPackageReleaseComponentsApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentPackageReleaseComponentsApi.md#create) | **POST** /pulp/api/v3/content/deb/package_release_components/ | Create a package release component
[**list**](ContentPackageReleaseComponentsApi.md#list) | **GET** /pulp/api/v3/content/deb/package_release_components/ | List package release components
[**read**](ContentPackageReleaseComponentsApi.md#read) | **GET** {deb_package_release_component_href} | Inspect a package release component



## create

> DebPackageReleaseComponentResponse create(deb_package_release_component)

Create a package release component

A PackageReleaseComponent associates a Package with a ReleaseComponent.  Associated artifacts: None; contains only metadata.  This simply stores the information which packages are part of which components.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentPackageReleaseComponentsApi.new
deb_package_release_component = PulpDebClient::DebPackageReleaseComponent.new # DebPackageReleaseComponent | 

begin
  #Create a package release component
  result = api_instance.create(deb_package_release_component)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentPackageReleaseComponentsApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_package_release_component** | [**DebPackageReleaseComponent**](DebPackageReleaseComponent.md)|  | 

### Return type

[**DebPackageReleaseComponentResponse**](DebPackageReleaseComponentResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## list

> PaginateddebPackageReleaseComponentResponseList list(opts)

List package release components

A PackageReleaseComponent associates a Package with a ReleaseComponent.  Associated artifacts: None; contains only metadata.  This simply stores the information which packages are part of which components.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentPackageReleaseComponentsApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  package: 'package_example', # String | Filter results where package matches value
  release_component: 'release_component_example', # String | Filter results where release_component matches value
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List package release components
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentPackageReleaseComponentsApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **package** | [**String**](.md)| Filter results where package matches value | [optional] 
 **release_component** | [**String**](.md)| Filter results where release_component matches value | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebPackageReleaseComponentResponseList**](PaginateddebPackageReleaseComponentResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> DebPackageReleaseComponentResponse read(deb_package_release_component_href, opts)

Inspect a package release component

A PackageReleaseComponent associates a Package with a ReleaseComponent.  Associated artifacts: None; contains only metadata.  This simply stores the information which packages are part of which components.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentPackageReleaseComponentsApi.new
deb_package_release_component_href = 'deb_package_release_component_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a package release component
  result = api_instance.read(deb_package_release_component_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentPackageReleaseComponentsApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_package_release_component_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebPackageReleaseComponentResponse**](DebPackageReleaseComponentResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

