# PulpDebClient::ContentReleaseArchitecturesApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentReleaseArchitecturesApi.md#create) | **POST** /pulp/api/v3/content/deb/release_architectures/ | Create a release architecture
[**list**](ContentReleaseArchitecturesApi.md#list) | **GET** /pulp/api/v3/content/deb/release_architectures/ | List release architectures
[**read**](ContentReleaseArchitecturesApi.md#read) | **GET** {deb_release_architecture_href} | Inspect a release architecture



## create

> DebReleaseArchitectureResponse create(deb_release_architecture)

Create a release architecture

A ReleaseArchitecture represents a single dpkg architecture string.  Associated artifacts: None; contains only metadata.  Every ReleaseArchitecture is always associated with exactly one Release. This indicates that the release/distribution in question supports this architecture.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentReleaseArchitecturesApi.new
deb_release_architecture = PulpDebClient::DebReleaseArchitecture.new # DebReleaseArchitecture | 

begin
  #Create a release architecture
  result = api_instance.create(deb_release_architecture)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentReleaseArchitecturesApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_release_architecture** | [**DebReleaseArchitecture**](DebReleaseArchitecture.md)|  | 

### Return type

[**DebReleaseArchitectureResponse**](DebReleaseArchitectureResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## list

> PaginateddebReleaseArchitectureResponseList list(opts)

List release architectures

A ReleaseArchitecture represents a single dpkg architecture string.  Associated artifacts: None; contains only metadata.  Every ReleaseArchitecture is always associated with exactly one Release. This indicates that the release/distribution in question supports this architecture.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentReleaseArchitecturesApi.new
opts = {
  architecture: 'architecture_example', # String | Filter results where architecture matches value
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  release: 'release_example', # String | Filter results where release matches value
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List release architectures
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentReleaseArchitecturesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **architecture** | **String**| Filter results where architecture matches value | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **release** | [**String**](.md)| Filter results where release matches value | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebReleaseArchitectureResponseList**](PaginateddebReleaseArchitectureResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> DebReleaseArchitectureResponse read(deb_release_architecture_href, opts)

Inspect a release architecture

A ReleaseArchitecture represents a single dpkg architecture string.  Associated artifacts: None; contains only metadata.  Every ReleaseArchitecture is always associated with exactly one Release. This indicates that the release/distribution in question supports this architecture.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentReleaseArchitecturesApi.new
deb_release_architecture_href = 'deb_release_architecture_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a release architecture
  result = api_instance.read(deb_release_architecture_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentReleaseArchitecturesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_release_architecture_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebReleaseArchitectureResponse**](DebReleaseArchitectureResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

