# PulpDebClient::ContentReleaseComponentsApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentReleaseComponentsApi.md#create) | **POST** /pulp/api/v3/content/deb/release_components/ | Create a release component
[**list**](ContentReleaseComponentsApi.md#list) | **GET** /pulp/api/v3/content/deb/release_components/ | List release components
[**read**](ContentReleaseComponentsApi.md#read) | **GET** {deb_release_component_href} | Inspect a release component



## create

> DebReleaseComponentResponse create(deb_release_component)

Create a release component

A ReleaseComponent represents a single APT repository component.  Associated artifacts: None; contains only metadata.  Every ReleaseComponent is always associated with exactly one Release. This indicates that the release/distribution in question contains this component.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentReleaseComponentsApi.new
deb_release_component = PulpDebClient::DebReleaseComponent.new # DebReleaseComponent | 

begin
  #Create a release component
  result = api_instance.create(deb_release_component)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentReleaseComponentsApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_release_component** | [**DebReleaseComponent**](DebReleaseComponent.md)|  | 

### Return type

[**DebReleaseComponentResponse**](DebReleaseComponentResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## list

> PaginateddebReleaseComponentResponseList list(opts)

List release components

A ReleaseComponent represents a single APT repository component.  Associated artifacts: None; contains only metadata.  Every ReleaseComponent is always associated with exactly one Release. This indicates that the release/distribution in question contains this component.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentReleaseComponentsApi.new
opts = {
  component: 'component_example', # String | Filter results where component matches value
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  release: 'release_example', # String | Filter results where release matches value
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List release components
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentReleaseComponentsApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **component** | **String**| Filter results where component matches value | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **release** | [**String**](.md)| Filter results where release matches value | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebReleaseComponentResponseList**](PaginateddebReleaseComponentResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> DebReleaseComponentResponse read(deb_release_component_href, opts)

Inspect a release component

A ReleaseComponent represents a single APT repository component.  Associated artifacts: None; contains only metadata.  Every ReleaseComponent is always associated with exactly one Release. This indicates that the release/distribution in question contains this component.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentReleaseComponentsApi.new
deb_release_component_href = 'deb_release_component_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a release component
  result = api_instance.read(deb_release_component_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentReleaseComponentsApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_release_component_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebReleaseComponentResponse**](DebReleaseComponentResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

