# PulpDebClient::ContentReleasesApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentReleasesApi.md#create) | **POST** /pulp/api/v3/content/deb/releases/ | Create a release
[**list**](ContentReleasesApi.md#list) | **GET** /pulp/api/v3/content/deb/releases/ | List releases
[**read**](ContentReleasesApi.md#read) | **GET** {deb_release_href} | Inspect a release



## create

> DebReleaseResponse create(deb_release)

Create a release

A Release represents a single APT release/distribution.  Associated artifacts: None; contains only metadata.  Note that in the context of the \"Release content\", the terms \"distribution\" and \"release\" are synonyms. An \"APT repository release/distribution\" is associated with a single 'Release' file below the 'dists/' folder. The \"distribution\" refers to the path between 'dists/' and the 'Release' file. The \"distribution\" could be considered the name of the \"release\". It is often (but not always) equal to the \"codename\" or \"suite\".

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentReleasesApi.new
deb_release = PulpDebClient::DebRelease.new # DebRelease | 

begin
  #Create a release
  result = api_instance.create(deb_release)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentReleasesApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_release** | [**DebRelease**](DebRelease.md)|  | 

### Return type

[**DebReleaseResponse**](DebReleaseResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## list

> PaginateddebReleaseResponseList list(opts)

List releases

A Release represents a single APT release/distribution.  Associated artifacts: None; contains only metadata.  Note that in the context of the \"Release content\", the terms \"distribution\" and \"release\" are synonyms. An \"APT repository release/distribution\" is associated with a single 'Release' file below the 'dists/' folder. The \"distribution\" refers to the path between 'dists/' and the 'Release' file. The \"distribution\" could be considered the name of the \"release\". It is often (but not always) equal to the \"codename\" or \"suite\".

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentReleasesApi.new
opts = {
  codename: 'codename_example', # String | Filter results where codename matches value
  distribution: 'distribution_example', # String | Filter results where distribution matches value
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  suite: 'suite_example', # String | Filter results where suite matches value
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List releases
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentReleasesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **codename** | **String**| Filter results where codename matches value | [optional] 
 **distribution** | **String**| Filter results where distribution matches value | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **suite** | **String**| Filter results where suite matches value | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebReleaseResponseList**](PaginateddebReleaseResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> DebReleaseResponse read(deb_release_href, opts)

Inspect a release

A Release represents a single APT release/distribution.  Associated artifacts: None; contains only metadata.  Note that in the context of the \"Release content\", the terms \"distribution\" and \"release\" are synonyms. An \"APT repository release/distribution\" is associated with a single 'Release' file below the 'dists/' folder. The \"distribution\" refers to the path between 'dists/' and the 'Release' file. The \"distribution\" could be considered the name of the \"release\". It is often (but not always) equal to the \"codename\" or \"suite\".

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentReleasesApi.new
deb_release_href = 'deb_release_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a release
  result = api_instance.read(deb_release_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentReleasesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_release_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebReleaseResponse**](DebReleaseResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

