# PulpDebClient::DistributionsAptApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](DistributionsAptApi.md#create) | **POST** /pulp/api/v3/distributions/deb/apt/ | Create an apt distribution
[**delete**](DistributionsAptApi.md#delete) | **DELETE** {deb_apt_distribution_href} | Delete an apt distribution
[**list**](DistributionsAptApi.md#list) | **GET** /pulp/api/v3/distributions/deb/apt/ | List apt distributions
[**partial_update**](DistributionsAptApi.md#partial_update) | **PATCH** {deb_apt_distribution_href} | Update an apt distribution
[**read**](DistributionsAptApi.md#read) | **GET** {deb_apt_distribution_href} | Inspect an apt distribution
[**update**](DistributionsAptApi.md#update) | **PUT** {deb_apt_distribution_href} | Update an apt distribution



## create

> AsyncOperationResponse create(deb_apt_distribution)

Create an apt distribution

Trigger an asynchronous create task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
deb_apt_distribution = PulpDebClient::DebAptDistribution.new # DebAptDistribution | 

begin
  #Create an apt distribution
  result = api_instance.create(deb_apt_distribution)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_distribution** | [**DebAptDistribution**](DebAptDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(deb_apt_distribution_href)

Delete an apt distribution

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
deb_apt_distribution_href = 'deb_apt_distribution_href_example' # String | 

begin
  #Delete an apt distribution
  result = api_instance.delete(deb_apt_distribution_href)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_distribution_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginateddebAptDistributionResponseList list(opts)

List apt distributions

An AptDistribution is just an AptPublication made available via the content app.  Creating an AptDistribution is a comparatively quick action. This way Pulp users may take as much time as is needed to prepare a VerbatimPublication or AptPublication, and then control the exact moment when that publication is made available.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
opts = {
  base_path: 'base_path_example', # String | 
  base_path__contains: 'base_path__contains_example', # String | Filter results where base_path contains value
  base_path__icontains: 'base_path__icontains_example', # String | Filter results where base_path contains value
  base_path__in: ['base_path__in_example'], # Array<String> | Filter results where base_path is in a comma-separated list of values
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List apt distributions
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **base_path** | **String**|  | [optional] 
 **base_path__contains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__icontains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__in** | [**Array&lt;String&gt;**](String.md)| Filter results where base_path is in a comma-separated list of values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebAptDistributionResponseList**](PaginateddebAptDistributionResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(deb_apt_distribution_href, patcheddeb_apt_distribution)

Update an apt distribution

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
deb_apt_distribution_href = 'deb_apt_distribution_href_example' # String | 
patcheddeb_apt_distribution = PulpDebClient::PatcheddebAptDistribution.new # PatcheddebAptDistribution | 

begin
  #Update an apt distribution
  result = api_instance.partial_update(deb_apt_distribution_href, patcheddeb_apt_distribution)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_distribution_href** | **String**|  | 
 **patcheddeb_apt_distribution** | [**PatcheddebAptDistribution**](PatcheddebAptDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> DebAptDistributionResponse read(deb_apt_distribution_href, opts)

Inspect an apt distribution

An AptDistribution is just an AptPublication made available via the content app.  Creating an AptDistribution is a comparatively quick action. This way Pulp users may take as much time as is needed to prepare a VerbatimPublication or AptPublication, and then control the exact moment when that publication is made available.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
deb_apt_distribution_href = 'deb_apt_distribution_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect an apt distribution
  result = api_instance.read(deb_apt_distribution_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_distribution_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebAptDistributionResponse**](DebAptDistributionResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(deb_apt_distribution_href, deb_apt_distribution)

Update an apt distribution

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
deb_apt_distribution_href = 'deb_apt_distribution_href_example' # String | 
deb_apt_distribution = PulpDebClient::DebAptDistribution.new # DebAptDistribution | 

begin
  #Update an apt distribution
  result = api_instance.update(deb_apt_distribution_href, deb_apt_distribution)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_distribution_href** | **String**|  | 
 **deb_apt_distribution** | [**DebAptDistribution**](DebAptDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

