# PulpDebClient::PublicationsVerbatimApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](PublicationsVerbatimApi.md#create) | **POST** /pulp/api/v3/publications/deb/verbatim/ | Create a verbatim publication
[**delete**](PublicationsVerbatimApi.md#delete) | **DELETE** {deb_verbatim_publication_href} | Delete a verbatim publication
[**list**](PublicationsVerbatimApi.md#list) | **GET** /pulp/api/v3/publications/deb/verbatim/ | List verbatim publications
[**read**](PublicationsVerbatimApi.md#read) | **GET** {deb_verbatim_publication_href} | Inspect a verbatim publication



## create

> AsyncOperationResponse create(deb_verbatim_publication)

Create a verbatim publication

Trigger an asynchronous task to publish content

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::PublicationsVerbatimApi.new
deb_verbatim_publication = PulpDebClient::DebVerbatimPublication.new # DebVerbatimPublication | 

begin
  #Create a verbatim publication
  result = api_instance.create(deb_verbatim_publication)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling PublicationsVerbatimApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_verbatim_publication** | [**DebVerbatimPublication**](DebVerbatimPublication.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> delete(deb_verbatim_publication_href)

Delete a verbatim publication

An VerbatimPublication is the Pulp-internal representation of a \"mirrored\" AptRepositoryVersion.  In other words, the verbatim publisher will recreate the synced subset of some a APT repository using the exact same metadata files and signatures as used by the upstream original. Once a Pulp publication has been created, it can be served by creating a Pulp distribution (in a near atomic action).

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::PublicationsVerbatimApi.new
deb_verbatim_publication_href = 'deb_verbatim_publication_href_example' # String | 

begin
  #Delete a verbatim publication
  api_instance.delete(deb_verbatim_publication_href)
rescue PulpDebClient::ApiError => e
  puts "Exception when calling PublicationsVerbatimApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_verbatim_publication_href** | **String**|  | 

### Return type

nil (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## list

> PaginateddebVerbatimPublicationResponseList list(opts)

List verbatim publications

An VerbatimPublication is the Pulp-internal representation of a \"mirrored\" AptRepositoryVersion.  In other words, the verbatim publisher will recreate the synced subset of some a APT repository using the exact same metadata files and signatures as used by the upstream original. Once a Pulp publication has been created, it can be served by creating a Pulp distribution (in a near atomic action).

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::PublicationsVerbatimApi.new
opts = {
  content: 'content_example', # String | Content Unit referenced by HREF
  content__in: 'content__in_example', # String | Content Unit referenced by HREF
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_created: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | ISO 8601 formatted dates are supported
  pulp_created__gt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is greater than value
  pulp_created__gte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is greater than or equal to value
  pulp_created__lt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is less than value
  pulp_created__lte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is less than or equal to value
  pulp_created__range: [DateTime.parse('2013-10-20T19:20:30+01:00')], # Array<DateTime> | Filter results where pulp_created is between two comma separated values
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List verbatim publications
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling PublicationsVerbatimApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **content** | **String**| Content Unit referenced by HREF | [optional] 
 **content__in** | **String**| Content Unit referenced by HREF | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_created** | **DateTime**| ISO 8601 formatted dates are supported | [optional] 
 **pulp_created__gt** | **DateTime**| Filter results where pulp_created is greater than value | [optional] 
 **pulp_created__gte** | **DateTime**| Filter results where pulp_created is greater than or equal to value | [optional] 
 **pulp_created__lt** | **DateTime**| Filter results where pulp_created is less than value | [optional] 
 **pulp_created__lte** | **DateTime**| Filter results where pulp_created is less than or equal to value | [optional] 
 **pulp_created__range** | [**Array&lt;DateTime&gt;**](DateTime.md)| Filter results where pulp_created is between two comma separated values | [optional] 
 **repository_version** | [**String**](.md)| Repository Version referenced by HREF | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebVerbatimPublicationResponseList**](PaginateddebVerbatimPublicationResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> DebVerbatimPublicationResponse read(deb_verbatim_publication_href, opts)

Inspect a verbatim publication

An VerbatimPublication is the Pulp-internal representation of a \"mirrored\" AptRepositoryVersion.  In other words, the verbatim publisher will recreate the synced subset of some a APT repository using the exact same metadata files and signatures as used by the upstream original. Once a Pulp publication has been created, it can be served by creating a Pulp distribution (in a near atomic action).

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::PublicationsVerbatimApi.new
deb_verbatim_publication_href = 'deb_verbatim_publication_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a verbatim publication
  result = api_instance.read(deb_verbatim_publication_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling PublicationsVerbatimApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_verbatim_publication_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebVerbatimPublicationResponse**](DebVerbatimPublicationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

