# PulpDebClient::RemotesAptApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](RemotesAptApi.md#create) | **POST** /pulp/api/v3/remotes/deb/apt/ | Create an apt remote
[**delete**](RemotesAptApi.md#delete) | **DELETE** {deb_apt_remote_href} | Delete an apt remote
[**list**](RemotesAptApi.md#list) | **GET** /pulp/api/v3/remotes/deb/apt/ | List apt remotes
[**partial_update**](RemotesAptApi.md#partial_update) | **PATCH** {deb_apt_remote_href} | Update an apt remote
[**read**](RemotesAptApi.md#read) | **GET** {deb_apt_remote_href} | Inspect an apt remote
[**update**](RemotesAptApi.md#update) | **PUT** {deb_apt_remote_href} | Update an apt remote



## create

> DebAptRemoteResponse create(deb_apt_remote)

Create an apt remote

An AptRemote represents an external APT repository content source.  It contains the location of the upstream APT repository, as well as the user options that are applied when using the remote to synchronize the upstream repository to Pulp.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
deb_apt_remote = PulpDebClient::DebAptRemote.new # DebAptRemote | 

begin
  #Create an apt remote
  result = api_instance.create(deb_apt_remote)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_remote** | [**DebAptRemote**](DebAptRemote.md)|  | 

### Return type

[**DebAptRemoteResponse**](DebAptRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(deb_apt_remote_href)

Delete an apt remote

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
deb_apt_remote_href = 'deb_apt_remote_href_example' # String | 

begin
  #Delete an apt remote
  result = api_instance.delete(deb_apt_remote_href)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_remote_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginateddebAptRemoteResponseList list(opts)

List apt remotes

An AptRemote represents an external APT repository content source.  It contains the location of the upstream APT repository, as well as the user options that are applied when using the remote to synchronize the upstream repository to Pulp.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  pulp_last_updated: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | ISO 8601 formatted dates are supported
  pulp_last_updated__gt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is greater than value
  pulp_last_updated__gte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is greater than or equal to value
  pulp_last_updated__lt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is less than value
  pulp_last_updated__lte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is less than or equal to value
  pulp_last_updated__range: [DateTime.parse('2013-10-20T19:20:30+01:00')], # Array<DateTime> | Filter results where pulp_last_updated is between two comma separated values
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List apt remotes
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **pulp_last_updated** | **DateTime**| ISO 8601 formatted dates are supported | [optional] 
 **pulp_last_updated__gt** | **DateTime**| Filter results where pulp_last_updated is greater than value | [optional] 
 **pulp_last_updated__gte** | **DateTime**| Filter results where pulp_last_updated is greater than or equal to value | [optional] 
 **pulp_last_updated__lt** | **DateTime**| Filter results where pulp_last_updated is less than value | [optional] 
 **pulp_last_updated__lte** | **DateTime**| Filter results where pulp_last_updated is less than or equal to value | [optional] 
 **pulp_last_updated__range** | [**Array&lt;DateTime&gt;**](DateTime.md)| Filter results where pulp_last_updated is between two comma separated values | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebAptRemoteResponseList**](PaginateddebAptRemoteResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(deb_apt_remote_href, patcheddeb_apt_remote)

Update an apt remote

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
deb_apt_remote_href = 'deb_apt_remote_href_example' # String | 
patcheddeb_apt_remote = PulpDebClient::PatcheddebAptRemote.new # PatcheddebAptRemote | 

begin
  #Update an apt remote
  result = api_instance.partial_update(deb_apt_remote_href, patcheddeb_apt_remote)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_remote_href** | **String**|  | 
 **patcheddeb_apt_remote** | [**PatcheddebAptRemote**](PatcheddebAptRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> DebAptRemoteResponse read(deb_apt_remote_href, opts)

Inspect an apt remote

An AptRemote represents an external APT repository content source.  It contains the location of the upstream APT repository, as well as the user options that are applied when using the remote to synchronize the upstream repository to Pulp.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
deb_apt_remote_href = 'deb_apt_remote_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect an apt remote
  result = api_instance.read(deb_apt_remote_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_remote_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebAptRemoteResponse**](DebAptRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(deb_apt_remote_href, deb_apt_remote)

Update an apt remote

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
deb_apt_remote_href = 'deb_apt_remote_href_example' # String | 
deb_apt_remote = PulpDebClient::DebAptRemote.new # DebAptRemote | 

begin
  #Update an apt remote
  result = api_instance.update(deb_apt_remote_href, deb_apt_remote)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_remote_href** | **String**|  | 
 **deb_apt_remote** | [**DebAptRemote**](DebAptRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

