# PulpDebClient::RepositoriesAptApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](RepositoriesAptApi.md#create) | **POST** /pulp/api/v3/repositories/deb/apt/ | Create an apt repository
[**delete**](RepositoriesAptApi.md#delete) | **DELETE** {deb_apt_repository_href} | Delete an apt repository
[**list**](RepositoriesAptApi.md#list) | **GET** /pulp/api/v3/repositories/deb/apt/ | List apt repositorys
[**modify**](RepositoriesAptApi.md#modify) | **POST** {deb_apt_repository_href}modify/ | Modify Repository Content
[**partial_update**](RepositoriesAptApi.md#partial_update) | **PATCH** {deb_apt_repository_href} | Update an apt repository
[**read**](RepositoriesAptApi.md#read) | **GET** {deb_apt_repository_href} | Inspect an apt repository
[**sync**](RepositoriesAptApi.md#sync) | **POST** {deb_apt_repository_href}sync/ | Sync from remote
[**update**](RepositoriesAptApi.md#update) | **PUT** {deb_apt_repository_href} | Update an apt repository



## create

> DebAptRepositoryResponse create(deb_apt_repository)

Create an apt repository

An AptRepository is the locally stored, Pulp-internal representation of a APT repository.  It may be filled with content via synchronization or content upload to create an AptRepositoryVersion.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RepositoriesAptApi.new
deb_apt_repository = PulpDebClient::DebAptRepository.new # DebAptRepository | 

begin
  #Create an apt repository
  result = api_instance.create(deb_apt_repository)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RepositoriesAptApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_repository** | [**DebAptRepository**](DebAptRepository.md)|  | 

### Return type

[**DebAptRepositoryResponse**](DebAptRepositoryResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(deb_apt_repository_href)

Delete an apt repository

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RepositoriesAptApi.new
deb_apt_repository_href = 'deb_apt_repository_href_example' # String | 

begin
  #Delete an apt repository
  result = api_instance.delete(deb_apt_repository_href)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RepositoriesAptApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_repository_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginateddebAptRepositoryResponseList list(opts)

List apt repositorys

An AptRepository is the locally stored, Pulp-internal representation of a APT repository.  It may be filled with content via synchronization or content upload to create an AptRepositoryVersion.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RepositoriesAptApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List apt repositorys
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RepositoriesAptApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebAptRepositoryResponseList**](PaginateddebAptRepositoryResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## modify

> AsyncOperationResponse modify(deb_apt_repository_href, repository_add_remove_content)

Modify Repository Content

Trigger an asynchronous task to create a new repository version.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RepositoriesAptApi.new
deb_apt_repository_href = 'deb_apt_repository_href_example' # String | 
repository_add_remove_content = PulpDebClient::RepositoryAddRemoveContent.new # RepositoryAddRemoveContent | 

begin
  #Modify Repository Content
  result = api_instance.modify(deb_apt_repository_href, repository_add_remove_content)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RepositoriesAptApi->modify: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_repository_href** | **String**|  | 
 **repository_add_remove_content** | [**RepositoryAddRemoveContent**](RepositoryAddRemoveContent.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(deb_apt_repository_href, patcheddeb_apt_repository)

Update an apt repository

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RepositoriesAptApi.new
deb_apt_repository_href = 'deb_apt_repository_href_example' # String | 
patcheddeb_apt_repository = PulpDebClient::PatcheddebAptRepository.new # PatcheddebAptRepository | 

begin
  #Update an apt repository
  result = api_instance.partial_update(deb_apt_repository_href, patcheddeb_apt_repository)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RepositoriesAptApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_repository_href** | **String**|  | 
 **patcheddeb_apt_repository** | [**PatcheddebAptRepository**](PatcheddebAptRepository.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> DebAptRepositoryResponse read(deb_apt_repository_href, opts)

Inspect an apt repository

An AptRepository is the locally stored, Pulp-internal representation of a APT repository.  It may be filled with content via synchronization or content upload to create an AptRepositoryVersion.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RepositoriesAptApi.new
deb_apt_repository_href = 'deb_apt_repository_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect an apt repository
  result = api_instance.read(deb_apt_repository_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RepositoriesAptApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_repository_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebAptRepositoryResponse**](DebAptRepositoryResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## sync

> AsyncOperationResponse sync(deb_apt_repository_href, repository_sync_url)

Sync from remote

Trigger an asynchronous task to sync content

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RepositoriesAptApi.new
deb_apt_repository_href = 'deb_apt_repository_href_example' # String | 
repository_sync_url = PulpDebClient::RepositorySyncURL.new # RepositorySyncURL | 

begin
  #Sync from remote
  result = api_instance.sync(deb_apt_repository_href, repository_sync_url)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RepositoriesAptApi->sync: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_repository_href** | **String**|  | 
 **repository_sync_url** | [**RepositorySyncURL**](RepositorySyncURL.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## update

> AsyncOperationResponse update(deb_apt_repository_href, deb_apt_repository)

Update an apt repository

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RepositoriesAptApi.new
deb_apt_repository_href = 'deb_apt_repository_href_example' # String | 
deb_apt_repository = PulpDebClient::DebAptRepository.new # DebAptRepository | 

begin
  #Update an apt repository
  result = api_instance.update(deb_apt_repository_href, deb_apt_repository)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RepositoriesAptApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_repository_href** | **String**|  | 
 **deb_apt_repository** | [**DebAptRepository**](DebAptRepository.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

